<?php



class WC_Gateway_StPays extends WC_Payment_Gateway_CC

{

    protected $APIXPay;

    protected $module_version;

    protected $oConfig;

    public static $alreadyEnqueuedDisplayCustomField = false;

    public static $alreadyEnqueuedDisplayCustomBadge = false;

    public static $alreadyEnqueuedDisplayCustomCulomn = false;

    public static $alreadyEnqueuedDisplayFilters = false;

    public static $alreadyEnqueuedCreateCustomField = false;

    public static $lastId = 0;

    public static $lastColumn = null;





    /**

     * Constructor

     */

    public function __construct()

    {


        $this->id = 'stpays';

        $this->method_title = 'StPays';

        $this->method_description = __('Consenti al cliente di pagare a rate.', 'stpays');



        $this->module_version = '2.0.4';



        $this->has_fields = true;

        $this->icon = plugins_url('assets/images/stpays.png', plugin_dir_path(__FILE__));



        //what plugin supports

        $this->supports = array(

            'products',

            'refunds'

        );



        //Set Config Form

        parent::init_settings();

        $this->oConfig = new WC_Gateway_StPays_Configuration($this->settings);
        

        $this->form_fields = $this->oConfig->get_form_fields();



        //Set Title of the Payment Method in BO

        $this->title = __('StPays', 'stpays');



        //Set Description on payment page

        $this->description = __('You can pay in installments of your amount', 'stpays');

        $this->instructions = $this->description;



        //Add JS script in Front and BO

        add_action('wp_enqueue_scripts', array($this, 'add_checkout_script'));

        add_action('admin_enqueue_scripts', array($this, 'add_admin_script'));

        add_action('woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'update_config' ));



        add_action('wp_ajax_calc_installments', array( $this, 'calc_installments' ));

        add_action('wp_ajax_nopriv_calc_installments', array( $this, 'calc_installments' ));

        add_action('wp_ajax_exp_check', array( $this, 'exp_check' ));

        add_action('wp_ajax_nopriv_exp_check', array( $this, 'exp_check' ));


        //Custom Field

        add_action('woocommerce_product_options_advanced', array( $this, 'stpays_create_custom_field' ));

        add_action('woocommerce_process_product_meta', array( $this,'stpays_save_custom_field'));

        add_action('woocommerce_before_add_to_cart_button', array( $this,'stpays_display_custom_field'));

        add_action('woocommerce_before_shop_loop_item_title', array( $this,'stpays_display_custom_badge'), 10, 0);

        //End Custom Field

        // add_action('woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'stpays_register_site' ));

        add_action('woocommerce_after_checkout_form', array($this,'checkout_script'));

        

        //Add Fiter in order page

        add_action('restrict_manage_posts', array( $this, 'filter_orders_by_payment_method'), 20);

        add_filter('request', array( $this, 'filter_orders_by_payment_method_query' ));

        //Add custom order status

        add_action('init', array( $this,'register_instalments_payment_order_status' ), 25);

        add_filter('wc_order_statuses', array( $this,'add_instalments_payment_to_order_statuses' ));

/*        add_filter('woocommerce_email_attachments', array( $this,'attach_contract_to_email'), 10, 3);*/

    }




    public function register_instalments_payment_order_status()

    {

        register_post_status('wc-incomplete-inst', array(

        'label'                     => __('Pagamento rate incompleto', 'stpays'),

        'public'                    => true,

        'exclude_from_search'       => false,

        'show_in_admin_all_list'    => true,

        'show_in_admin_status_list' => true,

        'label_count'               => _n_noop('Incompleto inst. (%s)', 'Incompleto inst. (%s)', 'stpays')

        ));



        register_post_status('wc-completed-inst', array(

        'label'                     => __('Pagamento rate completato', 'stpays'),

        'public'                    => true,

        'exclude_from_search'       => false,

        'show_in_admin_all_list'    => true,

        'show_in_admin_status_list' => true,

        'label_count'               => _n_noop('Completato inst. (%s)', 'Completato inst. (%s)', 'stpays')

        ));

    }

    public function add_instalments_payment_to_order_statuses($order_statuses)

    {

        return self::get_order_status($order_statuses);

    }



    public static function get_order_status($order_statuses)

    {

        $new_order_statuses = array();

        foreach ($order_statuses as $key => $status) {

            $new_order_statuses[ $key ] = $status;

        }

        $new_order_statuses['wc-incomplete-inst'] = __('Pagamento rate incompleto', 'stpays');

        $new_order_statuses['wc-completed-inst'] = __('Pagamento rate completato', 'stpays');

        return $new_order_statuses;

    }





    //Add Fiter in order page

    public function filter_orders_by_payment_method()

    {

        global $typenow;

        if (! self::$alreadyEnqueuedDisplayFilters) {

            if ('shop_order' === $typenow) {

                // get all payment methods, even inactive ones

                $gateways = WC()->payment_gateways->payment_gateways(); ?>

            <select name="_shop_order_payment_method" id="dropdown_shop_order_payment_method">

              <option value="">

                <?php esc_html_e('All Payment Methods', 'stpays'); ?>

              </option>



              <?php foreach ($gateways as $id => $gateway) : ?>

              <option value="<?php echo esc_attr($id); ?>" <?php echo esc_attr(isset($_GET['_shop_order_payment_method']) ? selected($id, $_GET['_shop_order_payment_method'], false) : ''); ?>>

                <?php echo esc_html($gateway->get_method_title()); ?>

              </option>

              <?php endforeach; ?>

            </select>

            <?php

            }

        }

        self::$alreadyEnqueuedDisplayFilters = true;

    }

    public function filter_orders_by_payment_method_query($vars)

    {

        global $typenow;

        if ('shop_order' === $typenow && isset($_GET['_shop_order_payment_method'])) {

            $vars['meta_key']   = '_payment_method';

            $vars['meta_value'] = wc_clean($_GET['_shop_order_payment_method']);

        }

        return $vars;

    }




    public function stpays_create_custom_field()

    {

        if (! self::$alreadyEnqueuedCreateCustomField) {

            $args = array(

             'id' => 'isInstallable',

             'label' => __('Prodotto rateizzabile', 'stpays'),

             'options' => array(0=>__('No', 'stpays'),1=>__('Sì', 'stpays')),

             'description' => __('Questo prodotto è rateizzabile?', 'stpays'),

           );

            woocommerce_wp_select($args);

           //  $args = array(

           //   'id' => 'maxInstallments',

           //   'label' => __('Max Installmets', 'stpays'),

           //   'options' => $this->getInstallments(),

           //   'description' => __('Maximum number of installments', 'stpays'),

           // );

           //  woocommerce_wp_select($args);





        }

        self::$alreadyEnqueuedCreateCustomField = true;

    }



    private function getInstallments()

    {

        for ($i=1;$i<=12;$i++) {

            $installments[$i] = $i;

        }

        return $installments;

    }



    public function stpays_save_custom_field($post_id)

    {

        $product = wc_get_product($post_id);

        $title = isset($_POST['isInstallable']) ? sanitize_text_field($_POST['isInstallable']) : '';

        $product->update_meta_data('isInstallable', $title);

        // $title = isset($_POST['maxInstallments']) ? sanitize_text_field($_POST['maxInstallments']) : '';

        // $product->update_meta_data('maxInstallments', $title);

        $product->save();

    }



    public function stpays_display_custom_badge()

    {

        global $post;

        $prod = wc_get_product($post->ID);

        if($prod !== false) {

            if ($post->ID != self::$lastId) {

                self::$alreadyEnqueuedDisplayCustomBadge = false;

            }



            if (!self::$alreadyEnqueuedDisplayCustomBadge) {

                self::$lastId = $post->ID;

                $isInstallable = $prod->get_meta('isInstallable');

                // $maxInstallments = $prod->get_meta('maxInstallments');

                $maxInstallments = $this->settings['sp_max_installments'];
               
                // $generalMaxInstallments = $this->settings['sp_max_installments'];

                // if ($generalMaxInstallments < $maxInstallments) {

                //     $maxInstallments = $generalMaxInstallments;

                // }

                if ($isInstallable) {

                    if ($isInstallable == 1) {

                        echo '<div class="stpays-custom-field-wrapper" >'

                            . '<span class="stpays-custom-badge" style="text-transform: uppercase;padding: 3px;width: 70%;max-width: 400px;margin-bottom: 1em;border: 1px solid;border-radius: 3px;/*color: black;border-color: black;*/display: inline-block;margin-top: 1em;"">'

                            . __('product available in', 'stpays')

                            . ' ' . $maxInstallments . ' ' . __('installments', 'stpays') . '</span>'

                            . '</div>';

                    }

                }

            }

            self::$alreadyEnqueuedDisplayCustomBadge = true;

        }

    }



    public function stpays_display_custom_field()

    {

        global $post;

        if (! self::$alreadyEnqueuedDisplayCustomField) {

            $product = wc_get_product($post->ID);

            if ($product !== false){

                $isInstallable = $product->get_meta('isInstallable');

            $maxInstallments = $product->get_meta('maxInstallments');

            $generalMaxInstallments = $this->settings['sp_max_installments'];

            if ($generalMaxInstallments < $maxInstallments) {

                $maxInstallments = $generalMaxInstallments;

            }

            if ($isInstallable) {

                if ($isInstallable == 1) {

                    echo '<div class="stpays-custom-field-wrapper" style="background-color: lightgrey;border-left-color: #f8b250;border-left-style: outset;padding: 15px;max-width: 400px;display: block;margin-bottom: 30px;"">'

                        . '<span style="/* float: left; *//* padding-right: 10px; */display: inline-block;">'

                        . '<h5 style="padding-left:10px;font-weight: bold;font-size: 14px;    line-height: 18px;">' . __('ACQUISTA A RATE', 'stpays') . '</h5>'

                        . '<h6 style="padding-left:10px;font-size: 13px;    line-height: 16px;">' . __('Puoi pagare questo prodotto a rate', 'stpays') . '</h6></span>'

                        . '<img src=' . plugins_url('assets/images/stpays.png', plugin_dir_path(__FILE__)) . ' style="max-height: 45px;float: right;max-width: 80px;/* display: block; */"><br></div>';

                }

            }

        }

        }

        self::$alreadyEnqueuedDisplayCustomField = true;

    }

    /**

     * End Custom Field

     */



    /*

     * Add JS & CSS to checkout page

     */

    public function add_checkout_script()

    {

        // wp_enqueue_script('stpays', plugins_url('assets/js/stpays.js', plugin_dir_path(__FILE__)), array(), $this->module_version, true);

        // wp_enqueue_style('style_stpays', plugins_url('assets/css/stpays.css', plugin_dir_path(__FILE__)));

        wp_enqueue_script('stpays_stripe', 'https://js.stripe.com/v3/', array(), $this->module_version);

    }





    /**

     * Add JS & CSS to WC BackOffice

     */

    public function add_admin_script()

    {

        wp_enqueue_style('stpays_style', plugins_url('assets/css/stpays.css', plugin_dir_path(__FILE__)));

        wp_enqueue_script('stpays_xpay_build_config', plugins_url('assets/js/stpays_back.js', plugin_dir_path(__FILE__)), array(), $this->module_version, true);

    }



    /**

     * Return true if StPays is avaiable between payment methods

     */

    public function is_available()

    {

        global $woocommerce;

        if (is_add_payment_method_page()) { //Check if user is not in add payment method page in his account

            return false;

        }

        // if (get_woocommerce_currency() !== "EUR") { //Check if currency is EURO

        //     return false;

        // }

        if (class_exists("WC_Subscriptions_Cart") && WC_Subscriptions_Cart::cart_contains_subscription()) { //Check if cart contains subscription

            return false;

        }

        //Check if there are no installable products in the cart

        $cartInstallablea = true;

        if ($woocommerce->cart != null) {
            foreach ($woocommerce->cart->get_cart() as $cart_item) {

                $product = wc_get_product($cart_item['product_id']);

                $isInstallable = $product->get_meta('isInstallable');

                if ($isInstallable == false) {

                    $cartInstallablea = false;

                }

            }
        }

        if ($cartInstallablea == false) {

            return false;

        }

        //Check if total cart amount is in range

        $amount = '';

        if (isset(WC()->cart->total)) {
            $amount = WC()->cart->total;
        }

        if (isset($this->settings['sp_min_cart']) && $this->settings['sp_min_cart'] != '') {

            $minAmount = ($this->settings['sp_min_cart']);

            if ($minAmount != 0 && $amount < $minAmount) {

                return false;

            }

        }

        if (isset($this->settings['sp_max_cart']) && $this->settings['sp_max_cart'] != '') {

            $maxAmount = ($this->settings['sp_max_cart']);

            if ($maxAmount != 0 && $amount > $maxAmount) {

                return false;

            }

        }

        return parent::is_available();

    }



    /**

     *

     */

    public function form()

    {

        global $woocommerce;



        // wp_enqueue_script('wc-credit-card-form');





        // $enviroment = $this->oConfig->enviroment;

        // $APIKEY = $this->oConfig->nexi_alias;

        $amount = floatval(preg_replace('#[^\d.]#', '', $woocommerce->cart->get_total()));

/*        $amount = 1;*/

        $timestamp = (time()) * 1000;

        // $url = $this->oConfig->url_notifica;

        // $urlPost = $this->oConfig->url_notifica;

        $urlBack = wc_get_cart_url();

        $maxCartInstallments = $this->settings['sp_max_installments'];
        
        $maxCartPeriodicity = $this->settings['sp_max_periodicity'];

        // foreach ($woocommerce->cart->get_cart() as $cart_item) {

        //     $product = wc_get_product($cart_item['product_id']);

        //     $maxProductInstallments = $product->get_meta('maxInstallments');

        //     if(!$maxProductInstallments){

        //         $maxProductInstallments = 1;

        //     }

        //     if ($maxProductInstallments < $maxCartInstallments) {

        //         $maxCartInstallments = $maxProductInstallments;

        //     }

        // }



        $urlJs = plugins_url('assets/js/stpays.js', plugin_dir_path(__FILE__)) . "?" . $this->module_version;



        $path = plugin_dir_path(__DIR__);

        include_once $path . 'templates/' . __FUNCTION__ . ".php";

    }



    /**

     * Funzione obbigatoria per WP, processa il pagamento e fa il redirect

     *

     * @param type $order_id

     * @return type

     */

    public function process_payment($order_id) {

        $result = 'failure';

        $order = new WC_Order($order_id);

        $config = get_option('woocommerce_stpays_settings');
        $config['sp_crm_url'] = "https://app.stpays.com";
            

        if (isset($_REQUEST['stripeToken']) && $_REQUEST['stripeToken'] != "") {

            $installments = sanitize_text_field($_REQUEST['installments']);

            $periodicity = sanitize_text_field($_REQUEST['periodicity']);

            $get_total = $order->get_total();
            $t_amount = floor(($get_total*100) / $installments);

            if($config['api_key']!="" && $config['sp_crm_url']!=""){
                $auth_url = $config['sp_crm_url']."/api/login";

                $login_args = [
                    'body'=> wp_json_encode(['apikey'=>$config['api_key']]),
                    'headers' => [
                        'Accept' => 'application/json',
                        'Content-Type' => 'application/json',
                    ],
                    'timeout'     => 60,
                    'redirection' => 5,
                    'blocking'    => true,
                    'httpversion' => '1.0',
                ];
                $response_login = wp_remote_post($auth_url,$login_args);
                if (isset($response_login['body'])) {
                    $response_login = json_decode($response_login['body'],true);
                    
                    if (isset($response_login['status']) and $response_login['status']=="success" and isset($response_login['token']) and $response_login['token'] != '') {
                        $post_data12 = array();
                        $post_data12['apikey'] = sanitize_text_field($config['api_key']);
                        // **** User 
                        $post_data12['name'] = sanitize_text_field($_REQUEST['billing_first_name']);
                        $post_data12['lastname'] = sanitize_text_field($_REQUEST['billing_last_name']);
                        $post_data12['email'] = sanitize_email($_REQUEST['billing_email']);
                        $post_data12['mobile'] = sanitize_text_field($_REQUEST['billing_phone']);
                        // **** Subscription
                        $post_data12['quotes'] = sanitize_text_field($_REQUEST['installments']);
                        $post_data12['date_start'] = sanitize_text_field(date("Y-m-d"));
                        $post_data12['periodicity'] = sanitize_text_field($_REQUEST['periodicity']);
                        $post_data12['type_payment'] = 'installments';
                        $post_data12['amount'] = sanitize_text_field($order->get_total());
                        $post_data12['pre_payment'] = sanitize_text_field($t_amount);
                        $post_data12['closed'] = "0";
                        $post_data12['payment_method'] = sanitize_text_field($_REQUEST['stripeToken']);
                        // **** Shipping
                        $post_data12['shipping']['country'] = sanitize_text_field((isset($_REQUEST['shipping_country'])) ? $_REQUEST['shipping_country'] : $_REQUEST['billing_country']);
                        $post_data12['shipping']['address'] = sanitize_text_field((isset($_REQUEST['shipping_address_1'])) ? $_REQUEST['shipping_address_1'] :  $_REQUEST['billing_address_1']);
                        $post_data12['shipping']['address1'] = sanitize_text_field((isset($_REQUEST['shipping_address_2'])) ? $_REQUEST['shipping_address_2'] : $_REQUEST['billing_address_2']);
                        $post_data12['shipping']['zip'] = sanitize_text_field((isset($_REQUEST['shipping_postcode'])) ? $_REQUEST['shipping_postcode'] : $_REQUEST['billing_postcode']);
                        $post_data12['shipping']['city'] = sanitize_text_field((isset($_REQUEST['shipping_city'])) ? $_REQUEST['shipping_city'] : $_REQUEST['billing_city']);
                        $post_data12['shipping']['province'] = sanitize_text_field((isset($_REQUEST['shipping_state'])) ? $_REQUEST['shipping_state'] : $_REQUEST['billing_state']);

                        $post_data12['billing']['country'] = sanitize_text_field($_REQUEST['billing_country']);
                        $post_data12['billing']['address'] = sanitize_text_field($_REQUEST['billing_address_1']);
                        $post_data12['billing']['address1'] = sanitize_text_field($_REQUEST['billing_address_2']);
                        $post_data12['billing']['zip'] = sanitize_text_field($_REQUEST['billing_postcode']);
                        $post_data12['billing']['city'] = sanitize_text_field($_REQUEST['billing_city']);
                        $post_data12['billing']['province'] = sanitize_text_field($_REQUEST['billing_state']);

                        $subscription_url = $config['sp_crm_url']."/api/v1/subscriptions";
                        $stpays_args = [
                            //'body'=> wp_json_encode($post_data12),
                            'body'=> $post_data12,
                            'headers' => [
                                'Accept' => 'application/json',
                                'Authorization' => 'Bearer '.$response_login['token'],
                            ],
                            'timeout'     => 60,
                            'redirection' => 5,
                            'blocking'    => true,
                            'httpversion' => '1.0',
                        ];
                        $response = wp_remote_post($subscription_url,$stpays_args);
                        if (isset($response['body'])) {
                            $success = json_decode($response['body']);
                            if($success->success==1){
                                $order->reduce_order_stock();

                                WC()->cart->empty_cart();
                                $order->payment_complete();
                                $order->update_status($config['sp_incomplete_status']);

                                return array(
                                    'result'    => 'success',
                                    'redirect'  => $this->get_return_url( $order )
                                );
                            }else{
                                wc_add_notice(__($success->message, 'stpays'), "error");
                                return false;
                            }
                        }else{
                            wc_add_notice(__($success->message, 'stpays'), "error");
                            return false;
                        }
                    }else{
                        wc_add_notice(__("Something went wrong2", 'stpays'), "error");
                        return false;
                    }
                }else{
                    wc_add_notice(__("Something went wrong3", 'stpays'), "error");
                    return false;
                }
            }else{
                wc_add_notice(__("Something went wrong4", 'stpays'), "error");
                return false;
            }
        }else{
            wc_add_notice(__("Something went wrong5", 'stpays'), "error");
            return false;
        }
    }



    /**

     * Save module config

     */

    public function update_config()

    {

        global $woocommerce;

        $this->process_admin_options();

    }



    /**

     * Calculate the installments amount

     */

    public function calc_installments($installments = null, $php = false, $periodicity = false)

    {

        $ret = array();

        if ($installments == null && !empty($_REQUEST['installments'])) {

            $installments = sanitize_text_field($_REQUEST['installments']);

        }

        if ($periodicity == null && !empty($_REQUEST['periodicity'])) {

            $periodicity = sanitize_text_field($_REQUEST['periodicity']);

        }

        global $woocommerce;

        $totalNF = $woocommerce->cart->total;

        $shippingNF = $woocommerce->cart->shipping_total;

        if (isset($installments) && $installments != 0) {
            // $installment_amountNF = floor((($totalNF*100)-($shippingNF*100)) / $installments);
            // $first_installment_amountNF = $installment_amountNF + ((($totalNF*100)-($shippingNF*100)) - ($installment_amountNF * $installments)) + ($shippingNF*100);
            $installment_amountNF = floor(($totalNF*100) / $installments);
            $first_installment_amountNF = $installment_amountNF;
        } else {

            $installment_amountNF = 0;

            $first_installment_amountNF = 0;

        }

        $installment_amount = $installment_amountNF / 100;

        //$installment_amount = number_format($installment_amount, 2, ',', ' ');

        $first_installment_amount = $first_installment_amountNF / 100;

        //$first_installment_amount = number_format($first_installment_amount, 2, ',', ' ');

        //$total = number_format($totalNF, 2, ',', ' ');

        $timestamp = (time()) * 1000;

        $res =  '<p class="stpays-p-size stpays-p-confirm">' . __('Il tuo piano rateale:', 'stpays') . '</p>' .

                '<table class="shop_table woocommerce-checkout-review-order-table stpays-table" >

                  <tr class="cart_item">

                    <th class="product-name stpays-installment" >' . __('Rata', 'stpays') . '</th>

                    <th class="product-name stpays-date" >' . __('Date', 'stpays') . '</th>

                    <th class="product-total stpays-amount" >' . __('Importo', 'stpays') . '</th>

                  </tr>';

        $res .= '  <tr class="cart_item">

              <td class="product-name stpays-installment" >1</td>

              <td class="product-name stpays-date" >' . __('Oggi', 'stpays') . '</td>

              <td class="product-total stpays-amount" >'.wc_price($first_installment_amount).'</td>

            </tr>';

        $date = new DateTime(date("Y-m-d"));

        for ($inst=2; $inst<=$installments; $inst++) {

            $date->modify('+'. $periodicity .' month');

            $res .= '  <tr class="cart_item">

              <td class="product-name stpays-installment" >' . $inst . '</td>

              <td class="product-name stpays-date" >' . $date->format('d/m/Y') . '</td>

              <td class="product-total stpays-amount" >' . wc_price($installment_amount). '</td>

            </tr>';

        }

        $res .= '  <tr class="cart_item">

          <td class="product-name stpays-total" colspan="2">' . __('Totale', 'stpays') . '</td>

          <td class="product-total stpays-amount" >' . wc_price($totalNF). '</td>

        </tr>';

        $res .= '</table>';

        $res .= '<input type="hidden" id="firstInstallmentAmount" name="firstInstallmentAmount"  value="' . $first_installment_amountNF . '"></input>';

        $res .= '<input type="hidden" id="firstInstallmentTimestamp" value="' . $timestamp . '"></input>';



        if ($php == false) {

            ob_clean();

            echo wp_kses_post($res);

            wp_die();

        } else {

            return array('installments'=>$installments,'periodicity'=>$periodicity,'total'=>$totalNF*100,'first'=>$first_installment_amountNF,'others'=>$installment_amountNF);

        }

    }



    public function exp_check($installments = null, $exp = null, $back = false)

    {

        $res = null;

        if ($installments == null && !empty($_REQUEST['installments'])) {

            $installments = sanitize_text_field($_REQUEST['installments']);

        }

        if ($installments == null && !empty($_REQUEST['installments'])) {

            $installments = sanitize_text_field($_REQUEST['installments']);

        }

        if ($exp == null && !empty($_REQUEST['exp'])) {

            $exp = sanitize_text_field($_REQUEST['exp']);

        }

        $expY = substr($exp, 0, 4);

        $expM = substr($exp, 4, 2);

        $installmentsEndDate = date('Y-m-d');

        $installmentsEndDate = strtotime(date("Y-m-d", strtotime($installmentsEndDate)) . " +" . ($installments - 1) . " month");

        $installmentsEndDateFormat = date("Y-m-d", $installmentsEndDate);

        $installmentsEndMonth = date("m", $installmentsEndDate);

        $installmentsEndYear = date("Y", $installmentsEndDate);

        if ($expY > $installmentsEndYear) {

            $res['compatible'] = true;

        } else {

            if ($expM > $installmentsEndMonth && $expY == $installmentsEndYear) {

                $res['compatible'] = true;

            } else {

                $actDate = new DateTime(date("Y-m-d"));

                $scad = new DateTime($expY . '-' . $expM);

                $scad = new DateTime($scad->format("Y-m-t"));

                $diff = $actDate->diff($scad)->m;

                $res['compatible'] = false;

                $res['maxInst'] = $diff;

            }

        }

        if ($back == true) {

            return $res['compatible'];

        }

        ob_clean();

        echo json_encode($res);

        wp_die();

    }



    /**

     * pagina di ricezione parametri

     */

    

    private function send_email_woocommerce_style($subject, $message, $email = null)

    {

        if ($email == null) {

            $email = get_option('admin_email');

        }

        $mailer = WC()->mailer();

        $wrapped_message = $mailer->wrap_message($subject, $message);

        $wc_email = new WC_Email;

        $html_message = $wc_email->style_inline($wrapped_message);

        wp_mail($email, $subject, $html_message, array('Content-Type: text/html; charset=UTF-8'));

    }



    /**

     * ritorna mac calcolato da inviare a pagina XPAY per pagamento

     *

     * @param type $params

     * @return type

     */







    public function checkout_script()

    {

        // wp_enqueue_script('stpays', plugins_url('assets/js/stpays.js', plugin_dir_path(__FILE__)), array(), $this->module_version, true);

        // wp_localize_script( "stpays", "stpays_ajax_url",  admin_url( 'admin-ajax.php' ));


        wp_enqueue_style('style_stpays', plugins_url('assets/css/stpays.css', plugin_dir_path(__FILE__)));


        wp_register_script( "stpays", plugins_url('assets/js/stpays.js', plugin_dir_path(__FILE__)), array(), $this->module_version, true);
        wp_localize_script( 'stpays', 'myAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' )));        

        // wp_enqueue_script( 'jquery' );
        wp_enqueue_script( 'stpays' );
    }




    /**

     * restituisce la versione di woocommerce da mettere nelle note del

     * pagamento

     *

     * @return type

     */

    public function wpbo_get_woo_version_number_stpays()

    {

        // If get_plugins() isn't available, require it

        if (!function_exists('get_plugins')) {

            require_once(ABSPATH . 'wp-admin/includes/plugin.php');

        }



        // Create the plugins folder and file variables

        $plugin_folder = get_plugins('/' . 'woocommerce');

        $plugin_file = 'woocommerce.php';



        // If the plugin version number is set, return it

        if (isset($plugin_folder[$plugin_file]['Version'])) {

            return $plugin_folder[$plugin_file]['Version'];

        } else {

            // Otherwise return null

            return null;

        }

    }

}