<?php



/**

 * Plugin Name: StPays

 * Plugin URI:

 * Description: Official StPays plugin.

 * Version: 1.0.0

 * Author: StPays 

 * Text Domain: stpays

 */



/**

 * Required functions

 */

if (!defined('ABSPATH')) {

    exit;

}



define('SPWC_PLUGIN_VERSION', '2.0.4');



class WC_StPays

{



    /**

     * Plugin's version.

     *

     * @since 1.1.4

     *

     * @var string

     */

    public $version;



    /**

     * Plugin's absolute path.

     *

     * @var string

     */

    public $path;



    /**

     * Plugin's URL.

     *

     * @since 1.1.4

     *

     * @var string

     */

    public $plugin_url;



    /**

     * Constructor

     */

    public function __construct()

    {

        $this->version = SPWC_PLUGIN_VERSION; //CHANGE



        $this->path = untrailingslashit(plugin_dir_path(__FILE__));

        $this->plugin_url = untrailingslashit(plugins_url('/', __FILE__));



        add_action('init', array($this, 'init'));

        add_action('admin_init', array($this, 'admin_init'));



        add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'my_plugin_action_links'));



        //Add custom page for terms and condition

        add_filter('init', function ($template) {

            if (isset($_GET['tos'])) {

                $tos = sanitize_text_field($_GET['tos']);

                include plugin_dir_path(__FILE__) . 'templates/tos.php';

                die;

            }

        });

    }



    /**

     * Init

     */

    public function init()

    {

        if (!$this->wc_stpays_is_plugin_woocommerce_active()) {

            add_action('admin_notices', function () {

                $msg = __('StPays is inactive because WooCommerce is not installed.', 'stpays');

                echo wp_kses_post('<div class="error"><p>' . $msg . '</p></div>');

            });

            return;

        }



        $this->load_plugin_textdomain();

        $this->init_gateway();

        $this->init_admin_order_details();

    }



    /**

     * Ogni volta che si ricarica la pagina admin

     * si può fare controlli e fare uscire alert

     */

    public function admin_init()

    {

    }



    public static function wc_stpays_is_plugin_woocommerce_active()

    {

        $active_plugins = (array) get_option('active_plugins', array());

        return in_array('woocommerce/woocommerce.php', $active_plugins) || array_key_exists('woocommerce/woocommerce.php', $active_plugins) || preg_grep("/woocommerce.php/", $active_plugins);

    }



    public function my_plugin_action_links($links)

    {

        $section = 'stpays';

        $plugin_links = array(

            '<a href="' . admin_url('admin.php?page=wc-settings&tab=checkout&section=' . $section) . '">' . __('Settings', 'stpays') . '</a>',

        );

        return array_merge($plugin_links, $links);

    }



    /**

     * Init gateway

     */

    public function init_gateway()

    {

        if (!class_exists('WC_Payment_Gateway')) {

            return;

        }

        // include_once($this->path . '/includes/config_stpays.php');

        include_once($this->path . '/includes/class-wc-gateway-stpays.php');

        include_once($this->path . '/includes/class-wc-gateway-stpays-configuration.php');

        include_once($this->path . '/includes/class-wc-gateway-stpays-order-payment-info.php');



        $this->gateway = new WC_Gateway_StPays();



        add_filter('woocommerce_payment_gateways', array($this, 'add_gateway'));

    }



    /**

     * Load translations.

     *

     * @since 1.1.4

     */

    public function load_plugin_textdomain()

    {

        load_plugin_textdomain('stpays', false, dirname(plugin_basename(__FILE__)) . '/lang');

    }



    /**

     * Add StPays to WC Gateways.

     *

     * @param array $methods List of payment methods.

     *

     * @return array List of payment methods.

     */

    public function add_gateway($methods)

    {

        $methods[] = $this->gateway;



        return $methods;

    }



    /**

     *

     */

    public function init_admin_order_details()

    {

        include_once($this->path . '/includes/class-wc-gateway-stpays-admin-order-details.php');



        $this->admin_order_details = new WC_Gateway_StPays_Admin_Order_Details();

        $this->admin_order_details->set_meta_box_stpays();

    }



    /**

     *

     */

    public function xpay_style_scripts()

    {

        //wp_register_style('xpay-style', plugins_url('assets/css/stpays.css', plugin_dir_path(__FILE__)));

        woocommerce_enqueue_styles('xpay-style', plugins_url('assets/css/stpays.css', plugin_dir_path(__FILE__)));

        //wp_enqueue_script('xpay-script', plugins_url('assets/js/xpay.js', plugin_dir_path(__FILE__)));

    }



    public static function is_plugin_woocommerce_active()

    {

        $active_plugins = (array) get_option('active_plugins', array());

        return in_array('woocommerce/woocommerce.php', $active_plugins) || array_key_exists('woocommerce/woocommerce.php', $active_plugins);

    }



    public function is_plugin_stpays_active()

    {

        return is_plugin_active('stpays/stpays.php');

    }



    public function deactivate_plugins()

    {

        deactivate_plugins('stpays/stpays.php');

    }

}



/**

 * Get order property with compatibility for WC lt 3.0.

 *

 * @since 1.7.0

 *

 * @param WC_Order $order Order object.

 * @param string   $key   Order property.

 *

 * @return mixed Value of order property.

 */

function wc_sp_get_order_prop($order, $key)

{

    switch ($key) {

        case 'order_currency':

            return is_callable(array($order, 'get_currency')) ? $order->get_currency() : $order->get_order_currency();

            break;

        default:

            $getter = array($order, 'get_' . $key);

            return is_callable($getter) ? call_user_func($getter) : $order->{ $key };

    }

}



/**

 * Return instance of WC_StPays.

 *

 * @since 1.1.4

 *

 * @return WC_StPays

 */

function wc_stpays()

{

    static $plugin;



    if (!isset($plugin)) {

        $plugin = new WC_StPays();

    }



    return $plugin;

}



// Provides backward compatibility.

$GLOBALS['wc_gateway_stpays'] = wc_stpays();

add_filter( 'woocommerce_billing_fields', 'ts_unrequire_wc_phone_field');
function ts_unrequire_wc_phone_field( $fields ) {
    $fields['billing_address_2']['required'] = true;
    $fields['billing_address_2']['class'][3] = "validate-required";
    // echo "<pre>";
    // print_r($fields);
    // exit;
    // $fields['shipping_address_2']['required'] = true;
    return $fields;
}

add_filter( 'woocommerce_shipping_fields', 'ts_unrequire_wc_phone_field_shipping');
function ts_unrequire_wc_phone_field_shipping( $fields ) {
    // $fields['billing_address_2']['required'] = true;
    $fields['shipping_address_2']['required'] = true;
    return $fields;
}